@@ -5,6 +5,7 @@
 
 #define N 16
 
+__attribute__ ((noinline))
 int main1 (int a, int b)
 {
   int i, j;
@@ -41,6 +42,6 @@ int main (void)
   return main1 (2 ,7);
 }
 
-/* { dg-final { scan-tree-dump-times "vectorized 1 loops" 1 "vect"  { xfail *-*-* } } } */
+/* { dg-final { scan-tree-dump-times "vectorized 1 loops" 1 "vect"  } } */
 /* { dg-final { scan-tree-dump-times "Vectorizing an unaligned access" 0 "vect" } } */
 /* { dg-final { cleanup-tree-dump "vect" } } */
